@@ -22,6 +22,7 @@ import collections
 import itertools
 import random
 
+from keystoneauth1 import exceptions as ka_exceptions
 from keystoneclient import exceptions as ks_exceptions
 from oslo_config import cfg
 from oslo_context import context
@@ -33,7 +34,7 @@ from stevedore import extension
 
 from ceilometer.agent import plugin_base
 from ceilometer import coordination
-from ceilometer.i18n import _, _LI, _LE, _LW
+from ceilometer.i18n import _, _LE, _LI, _LW
 from ceilometer import keystone_client
 from ceilometer import messaging
 from ceilometer import pipeline
@@ -58,7 +59,6 @@ OPTS = [
 
 POLLING_OPTS = [
     cfg.StrOpt('partitioning_group_prefix',
-               default=None,
                deprecated_group='central',
                help='Work-load partitioning group prefix. Use only if you '
                     'want to run multiple polling agents with different '
@@ -174,13 +174,13 @@ class PollingTask(object):
                 # If no resources, skip for this pollster
                 if not polling_resources:
                     p_context = 'new ' if history else ''
-                    LOG.info(_("Skip pollster %(name)s, no %(p_context)s"
-                               "resources found this cycle"),
+                    LOG.info(_LI("Skip pollster %(name)s, no %(p_context)s"
+                                 "resources found this cycle"),
                              {'name': pollster.name, 'p_context': p_context})
                     continue
 
-                LOG.info(_("Polling pollster %(poll)s in the context of "
-                           "%(src)s"),
+                LOG.info(_LI("Polling pollster %(poll)s in the context of "
+                             "%(src)s"),
                          dict(poll=pollster.name, src=source_name))
                 try:
                     samples = pollster.obj.get_samples(
@@ -275,7 +275,7 @@ class AgentManager(service_base.BaseService):
         self.notifier = oslo_messaging.Notifier(
             messaging.get_transport(),
             driver=cfg.CONF.publisher_notifier.telemetry_driver,
-            publisher_id="ceilometer.api")
+            publisher_id="ceilometer.polling")
 
         self._keystone = None
         self._keystone_last_exception = None
@@ -286,7 +286,7 @@ class AgentManager(service_base.BaseService):
             # Extension raising ExtensionLoadError can be ignored,
             # and ignore anything we can't import as a safety measure.
             if isinstance(exc, plugin_base.ExtensionLoadError):
-                LOG.error(_("Skip loading extension for %s") % ep.name)
+                LOG.exception(_("Skip loading extension for %s") % ep.name)
                 return
             if isinstance(exc, ImportError):
                 LOG.error(_("Failed to import extension for %(name)s: "
@@ -411,7 +411,8 @@ class AgentManager(service_base.BaseService):
             try:
                 self._keystone = keystone_client.get_client()
                 self._keystone_last_exception = None
-            except ks_exceptions.ClientException as e:
+            except (ka_exceptions.ClientException,
+                    ks_exceptions.ClientException) as e:
                 self._keystone = None
                 self._keystone_last_exception = e
         if self._keystone is not None:
@@ -445,8 +446,9 @@ class AgentManager(service_base.BaseService):
                         service_type = getattr(
                             cfg.CONF.service_types,
                             discoverer.KEYSTONE_REQUIRED_FOR_SERVICE)
-                        if not self.keystone.service_catalog.get_endpoints(
-                                service_type=service_type):
+                        if not keystone_client.get_service_catalog(
+                                self.keystone).get_endpoints(
+                                    service_type=service_type):
                             LOG.warning(_LW(
                                 'Skipping %(name)s, %(service_type)s service '
                                 'is not registered in keystone'),
@@ -460,7 +462,8 @@ class AgentManager(service_base.BaseService):
                     resources.extend(partitioned)
                     if discovery_cache is not None:
                         discovery_cache[url] = partitioned
-                except ks_exceptions.ClientException as e:
+                except (ka_exceptions.ClientException,
+                        ks_exceptions.ClientException) as e:
                     LOG.error(_LE('Skipping %(name)s, keystone issue: '
                                   '%(exc)s'), {'name': name, 'exc': e})
                 except Exception as err:
