@@ -94,9 +94,9 @@ class SNMPInspector(base.Inspector):
      GetRequest for oids of 'metadata'.
 
      For matching_type of PREFIX, SNMP request GetBulkRequest
-     would be send to get values for oids of 'metric_oid' and
+     would be sent to get values for oids of 'metric_oid' and
      'metadata' of each item in the above mapping. And each item might
-     return multiple (value, metadata, extra) tuple, e.g.
+     return multiple (value, metadata, extra) tuples, e.g.
      Suppose we have the following mapping:
      MAPPING = {
       'disk.size.total': {
@@ -128,21 +128,29 @@ class SNMPInspector(base.Inspector):
          extra.update('project_id': xy, 'user_id': zw)
     """
 
+    def __init__(self):
+        super(SNMPInspector, self).__init__()
+        self._cmdGen = cmdgen.CommandGenerator()
+
     def _query_oids(self, host, oids, cache, is_bulk):
-        # send GetRequest or GetBulkRequest to get oid values and
+        # send GetRequest or GetBulkRequest to get oids values and
         # populate the values into cache
         authData = self._get_auth_strategy(host)
         transport = cmdgen.UdpTransportTarget((host.hostname,
                                                host.port or self._port))
         oid_cache = cache.setdefault(self._CACHE_KEY_OID, {})
 
-        cmd_runner = cmdgen.CommandGenerator()
         if is_bulk:
-            ret = cmd_runner.bulkCmd(authData, transport, 0, 100, *oids,
-                                     lookupValues=True)
+            ret = self._cmdGen.bulkCmd(authData,
+                                       transport,
+                                       0, 100,
+                                       *oids,
+                                       lookupValues=True)
         else:
-            ret = cmd_runner.getCmd(authData, transport, *oids,
-                                    lookupValues=True)
+            ret = self._cmdGen.getCmd(authData,
+                                      transport,
+                                      *oids,
+                                      lookupValues=True)
         (error, data) = parse_snmp_return(ret, is_bulk)
         if error:
             raise SNMPException("An error occurred, oids %(oid)s, "
@@ -154,10 +162,10 @@ class SNMPInspector(base.Inspector):
         if is_bulk:
             for var_bind_table_row in data:
                 for name, val in var_bind_table_row:
-                    oid_cache[name.prettyPrint()] = val
+                    oid_cache[str(name)] = val
         else:
             for name, val in data:
-                oid_cache[name.prettyPrint()] = val
+                oid_cache[str(name)] = val
 
     @staticmethod
     def find_matching_oids(oid_cache, oid, match_type, find_one=True):
