@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2013 eNovance <licensing@enovance.com>
+# Copyright 2013-2015 eNovance <licensing@enovance.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,6 +14,7 @@
 # under the License.
 
 from oslo_config import cfg
+import oslo_context.context
 import oslo_messaging
 from oslo_messaging import serializer as oslo_serializer
 
@@ -33,9 +34,8 @@ def get_transport(url=None, optional=False, cache=True):
     if not transport or not cache:
         try:
             transport = oslo_messaging.get_transport(cfg.CONF, url)
-        except (oslo_messaging.InvalidTransportURL,
-                oslo_messaging.DriverLoadFailure):
-            if not optional or url:
+        except oslo_messaging.InvalidTransportURL as e:
+            if not optional or e.url:
                 # NOTE(sileht): oslo_messaging is configured but unloadable
                 # so reraise the exception
                 raise
@@ -55,53 +55,57 @@ def cleanup():
         del TRANSPORTS[url]
 
 
-def get_rpc_server(transport, topic, endpoint):
-    """Return a configured oslo_messaging rpc server."""
-    cfg.CONF.import_opt('host', 'ceilometer.service')
-    target = oslo_messaging.Target(server=cfg.CONF.host, topic=topic)
-    serializer = oslo_serializer.RequestContextSerializer(
-        oslo_serializer.JsonPayloadSerializer())
-    return oslo_messaging.get_rpc_server(transport, target,
-                                         [endpoint], executor='eventlet',
-                                         serializer=serializer)
+class RequestContextSerializer(oslo_messaging.Serializer):
+
+    def __init__(self, base):
+        self._base = base
+
+    def serialize_entity(self, context, entity):
+        if not self._base:
+            return entity
+        return self._base.serialize_entity(context, entity)
+
+    def deserialize_entity(self, context, entity):
+        if not self._base:
+            return entity
+        return self._base.deserialize_entity(context, entity)
+
+    def serialize_context(self, context):
+        return context.to_dict()
+
+    def deserialize_context(self, context):
+        return oslo_context.context.RequestContext.from_dict(context)
 
 
-def get_rpc_client(transport, retry=None, **kwargs):
-    """Return a configured oslo_messaging RPCClient."""
-    target = oslo_messaging.Target(**kwargs)
-    serializer = oslo_serializer.RequestContextSerializer(
-        oslo_serializer.JsonPayloadSerializer())
-    return oslo_messaging.RPCClient(transport, target,
-                                    serializer=serializer,
-                                    retry=retry)
+_SERIALIZER = RequestContextSerializer(
+    oslo_serializer.JsonPayloadSerializer())
 
 
-def get_notification_listener(transport, targets, endpoints,
-                              allow_requeue=False):
+def get_batch_notification_listener(transport, targets, endpoints,
+                                    allow_requeue=False,
+                                    batch_size=1, batch_timeout=None):
     """Return a configured oslo_messaging notification listener."""
-    return oslo_messaging.get_notification_listener(
-        transport, targets, endpoints, executor='eventlet',
-        allow_requeue=allow_requeue)
+    return oslo_messaging.get_batch_notification_listener(
+        transport, targets, endpoints, executor='threading',
+        allow_requeue=allow_requeue,
+        batch_size=batch_size, batch_timeout=batch_timeout)
 
 
 def get_notifier(transport, publisher_id):
     """Return a configured oslo_messaging notifier."""
-    serializer = oslo_serializer.RequestContextSerializer(
-        oslo_serializer.JsonPayloadSerializer())
-    notifier = oslo_messaging.Notifier(transport, serializer=serializer)
+    notifier = oslo_messaging.Notifier(transport, serializer=_SERIALIZER)
     return notifier.prepare(publisher_id=publisher_id)
 
 
-def convert_to_old_notification_format(priority, ctxt, publisher_id,
-                                       event_type, payload, metadata):
+def convert_to_old_notification_format(priority, notification):
     # FIXME(sileht): temporary convert notification to old format
     # to focus on oslo_messaging migration before refactoring the code to
     # use the new oslo_messaging facilities
-    notification = {'priority': priority,
-                    'payload': payload,
-                    'event_type': event_type,
-                    'publisher_id': publisher_id}
-    notification.update(metadata)
-    for k in ctxt:
-        notification['_context_' + k] = ctxt[k]
+    notification = notification.copy()
+    notification['priority'] = priority
+    notification.update(notification["metadata"])
+    for k in notification['ctxt']:
+        notification['_context_' + k] = notification['ctxt'][k]
+    del notification['ctxt']
+    del notification['metadata']
     return notification
