@@ -16,6 +16,7 @@
 import abc
 import collections
 
+from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import timeutils
 import six
@@ -32,8 +33,32 @@ LBStatsData = collections.namedtuple(
     ['active_connections', 'total_connections', 'bytes_in', 'bytes_out']
 )
 
+LOAD_BALANCER_STATUS_V2 = {
+    'offline': 0,
+    'online': 1,
+    'no_monitor': 3,
+    'error': 4,
+    'degraded': 5
+}
 
-class LBPoolPollster(base.BaseServicesPollster):
+
+class BaseLBPollster(base.BaseServicesPollster):
+    """Base Class for Load Balancer pollster"""
+
+    def __init__(self):
+        super(BaseLBPollster, self).__init__()
+        self.lb_version = cfg.CONF.service_types.neutron_lbaas_version
+
+    def get_load_balancer_status_id(self, value):
+        if self.lb_version == 'v1':
+            resource_status = self.get_status_id(value)
+        elif self.lb_version == 'v2':
+            status = value.lower()
+            resource_status = LOAD_BALANCER_STATUS_V2.get(status, -1)
+        return resource_status
+
+
+class LBPoolPollster(BaseLBPollster):
     """Pollster to capture Load Balancer pool status samples."""
 
     FIELDS = ['admin_state_up',
@@ -57,12 +82,12 @@ class LBPoolPollster(base.BaseServicesPollster):
 
         for pool in resources:
             LOG.debug("Load Balancer Pool : %s" % pool)
-            status = self.get_status_id(pool['status'])
+            status = self.get_load_balancer_status_id(pool['status'])
             if status == -1:
                 # unknown status, skip this sample
-                LOG.warn(_("Unknown status %(stat)s received on pool %(id)s, "
-                           "skipping sample") % {'stat': pool['status'],
-                                                 'id': pool['id']})
+                LOG.warning(_("Unknown status %(stat)s received on pool "
+                              "%(id)s, skipping sample")
+                            % {'stat': pool['status'], 'id': pool['id']})
                 continue
 
             yield sample.Sample(
@@ -108,9 +133,9 @@ class LBVipPollster(base.BaseServicesPollster):
             status = self.get_status_id(vip['status'])
             if status == -1:
                 # unknown status, skip this sample
-                LOG.warn(_("Unknown status %(stat)s received on vip %(id)s, "
-                         "skipping sample") % {'stat': vip['status'],
-                                               'id': vip['id']})
+                LOG.warning(_("Unknown status %(stat)s received on vip "
+                              "%(id)s, skipping sample")
+                            % {'stat': vip['status'], 'id': vip['id']})
                 continue
 
             yield sample.Sample(
@@ -126,7 +151,7 @@ class LBVipPollster(base.BaseServicesPollster):
             )
 
 
-class LBMemberPollster(base.BaseServicesPollster):
+class LBMemberPollster(BaseLBPollster):
     """Pollster to capture Load Balancer Member status samples."""
 
     FIELDS = ['admin_state_up',
@@ -147,11 +172,11 @@ class LBMemberPollster(base.BaseServicesPollster):
 
         for member in resources:
             LOG.debug("Load Balancer Member : %s" % member)
-            status = self.get_status_id(member['status'])
+            status = self.get_load_balancer_status_id(member['status'])
             if status == -1:
-                LOG.warn(_("Unknown status %(stat)s received on member %(id)s,"
-                         "skipping sample") % {'stat': member['status'],
-                                               'id': member['id']})
+                LOG.warning(_("Unknown status %(stat)s received on member "
+                              "%(id)s, skipping sample")
+                            % {'stat': member['status'], 'id': member['id']})
                 continue
             yield sample.Sample(
                 name='network.services.lb.member',
@@ -208,6 +233,7 @@ class _LBStatsPollster(base.BaseServicesPollster):
     def __init__(self):
         super(_LBStatsPollster, self).__init__()
         self.client = neutron_client.Client()
+        self.lb_version = cfg.CONF.service_types.neutron_lbaas_version
 
     @staticmethod
     def make_sample_from_pool(pool, name, type, unit, volume,
@@ -238,22 +264,49 @@ class _LBStatsPollster(base.BaseServicesPollster):
             )
         return i_cache[pool_id]
 
+    def _populate_stats_cache_v2(self, loadbalancer_id, cache):
+        i_cache = cache.setdefault("lbstats", {})
+        if loadbalancer_id not in i_cache:
+            stats = self.client.get_loadbalancer_stats(loadbalancer_id)
+            i_cache[loadbalancer_id] = LBStatsData(
+                active_connections=stats['active_connections'],
+                total_connections=stats['total_connections'],
+                bytes_in=stats['bytes_in'],
+                bytes_out=stats['bytes_out'],
+            )
+        return i_cache[loadbalancer_id]
+
     @property
     def default_discovery(self):
-        return 'lb_pools'
+        discovery_resource = 'lb_pools'
+        if self.lb_version == 'v2':
+            discovery_resource = 'lb_loadbalancers'
+        return discovery_resource
 
     @abc.abstractmethod
     def _get_sample(pool, c_data):
         """Return one Sample."""
 
     def get_samples(self, manager, cache, resources):
-        for pool in resources:
-            try:
-                c_data = self._populate_stats_cache(pool['id'], cache)
-                yield self._get_sample(pool, c_data)
-            except Exception as err:
-                LOG.exception(_('Ignoring pool %(pool_id)s: %(error)s'),
-                              {'pool_id': pool['id'], 'error': err})
+        if self.lb_version == 'v1':
+            for pool in resources:
+                try:
+                    c_data = self._populate_stats_cache(pool['id'], cache)
+                    yield self._get_sample(pool, c_data)
+                except Exception:
+                    LOG.exception(_('Ignoring pool %(pool_id)s'),
+                                  {'pool_id': pool['id']})
+        elif self.lb_version == 'v2':
+            for loadbalancer in resources:
+                try:
+                    c_data = self._populate_stats_cache_v2(loadbalancer['id'],
+                                                           cache)
+                    yield self._get_sample(loadbalancer, c_data)
+                except Exception:
+                    LOG.exception(
+                        _('Ignoring '
+                          'loadbalancer %(loadbalancer_id)s'),
+                        {'loadbalancer_id': loadbalancer['id']})
 
 
 class LBActiveConnectionsPollster(_LBStatsPollster):
@@ -292,7 +345,7 @@ class LBBytesInPollster(_LBStatsPollster):
         return make_sample_from_pool(
             pool,
             name='network.services.lb.incoming.bytes',
-            type=sample.TYPE_CUMULATIVE,
+            type=sample.TYPE_GAUGE,
             unit='B',
             volume=data.bytes_in,
         )
@@ -306,7 +359,7 @@ class LBBytesOutPollster(_LBStatsPollster):
         return make_sample_from_pool(
             pool,
             name='network.services.lb.outgoing.bytes',
-            type=sample.TYPE_CUMULATIVE,
+            type=sample.TYPE_GAUGE,
             unit='B',
             volume=data.bytes_out,
         )
@@ -327,3 +380,94 @@ def make_sample_from_pool(pool, name, type, unit, volume,
         timestamp=timeutils.utcnow().isoformat(),
         resource_metadata=resource_metadata,
     )
+
+
+class LBListenerPollster(BaseLBPollster):
+    """Pollster to capture Load Balancer Listener status samples."""
+
+    FIELDS = ['admin_state_up',
+              'connection_limit',
+              'description',
+              'name',
+              'default_pool_id',
+              'protocol',
+              'protocol_port',
+              'operating_status',
+              'loadbalancers'
+              ]
+
+    @property
+    def default_discovery(self):
+        return 'lb_listeners'
+
+    def get_samples(self, manager, cache, resources):
+        resources = resources or []
+
+        for listener in resources:
+            LOG.debug("Load Balancer Listener : %s" % listener)
+            status = self.get_load_balancer_status_id(
+                listener['operating_status'])
+            if status == -1:
+                # unknown status, skip this sample
+                LOG.warning(_("Unknown status %(stat)s received on listener "
+                              "%(id)s, skipping sample")
+                            % {'stat': listener['operating_status'],
+                               'id': listener['id']})
+                continue
+
+            yield sample.Sample(
+                name='network.services.lb.listener',
+                type=sample.TYPE_GAUGE,
+                unit='listener',
+                volume=status,
+                user_id=None,
+                project_id=listener['tenant_id'],
+                resource_id=listener['id'],
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata=self.extract_metadata(listener)
+            )
+
+
+class LBLoadBalancerPollster(BaseLBPollster):
+    """Pollster to capture Load Balancer status samples."""
+
+    FIELDS = ['admin_state_up',
+              'description',
+              'vip_address',
+              'listeners',
+              'name',
+              'vip_subnet_id',
+              'operating_status',
+              ]
+
+    @property
+    def default_discovery(self):
+        return 'lb_loadbalancers'
+
+    def get_samples(self, manager, cache, resources):
+        resources = resources or []
+
+        for loadbalancer in resources:
+            LOG.debug("Load Balancer: %s" % loadbalancer)
+            status = self.get_load_balancer_status_id(
+                loadbalancer['operating_status'])
+            if status == -1:
+                # unknown status, skip this sample
+                LOG.warning(_("Unknown status %(stat)s received "
+                              "on Load Balancer "
+                              "%(id)s, skipping sample")
+                            % {'stat': loadbalancer['operating_status'],
+                               'id': loadbalancer['id']})
+                continue
+
+            yield sample.Sample(
+                name='network.services.lb.loadbalancer',
+                type=sample.TYPE_GAUGE,
+                unit='loadbalancer',
+                volume=status,
+                user_id=None,
+                project_id=loadbalancer['tenant_id'],
+                resource_id=loadbalancer['id'],
+                timestamp=timeutils.utcnow().isoformat(),
+                resource_metadata=self.extract_metadata(loadbalancer)
+            )
