@@ -19,6 +19,7 @@
 
 import abc
 import hashlib
+from itertools import chain
 import os
 
 from oslo_config import cfg
@@ -31,7 +32,7 @@ import yaml
 
 
 from ceilometer.event.storage import models
-from ceilometer.i18n import _, _LW
+from ceilometer.i18n import _, _LI, _LW
 from ceilometer import publisher
 from ceilometer.publisher import utils as publisher_utils
 from ceilometer import sample as sample_util
@@ -83,12 +84,13 @@ class PipelineEndpoint(object):
         self.publish_context = PublishContext(context, [pipeline])
 
     @abc.abstractmethod
-    def sample(self, ctxt, publisher_id, event_type, payload, metadata):
+    def sample(self, messages):
         pass
 
 
 class SamplePipelineEndpoint(PipelineEndpoint):
-    def sample(self, ctxt, publisher_id, event_type, payload, metadata):
+    def sample(self, messages):
+        samples = chain.from_iterable(m["payload"] for m in messages)
         samples = [
             sample_util.Sample(name=s['counter_name'],
                                type=s['counter_type'],
@@ -100,7 +102,7 @@ class SamplePipelineEndpoint(PipelineEndpoint):
                                timestamp=s['timestamp'],
                                resource_metadata=s['resource_metadata'],
                                source=s.get('source'))
-            for s in payload if publisher_utils.verify_signature(
+            for s in samples if publisher_utils.verify_signature(
                 s, cfg.CONF.publisher.telemetry_secret)
         ]
         with self.publish_context as p:
@@ -108,7 +110,8 @@ class SamplePipelineEndpoint(PipelineEndpoint):
 
 
 class EventPipelineEndpoint(PipelineEndpoint):
-    def sample(self, ctxt, publisher_id, event_type, payload, metadata):
+    def sample(self, messages):
+        events = chain.from_iterable(m["payload"] for m in messages)
         events = [
             models.Event(
                 message_id=ev['message_id'],
@@ -119,7 +122,7 @@ class EventPipelineEndpoint(PipelineEndpoint):
                                      models.Trait.convert_value(dtype, value))
                         for name, dtype, value in ev['traits']],
                 raw=ev.get('raw', {}))
-            for ev in payload if publisher_utils.verify_signature(
+            for ev in events if publisher_utils.verify_signature(
                 ev, cfg.CONF.publisher.telemetry_secret)
         ]
         try:
@@ -293,11 +296,7 @@ class EventSource(Source):
 
     def __init__(self, cfg):
         super(EventSource, self).__init__(cfg)
-        try:
-            self.events = cfg['events']
-        except KeyError as err:
-            raise PipelineException(
-                "Required field %s not specified" % err.args[0], cfg)
+        self.events = cfg.get('events')
         self.check_source_filtering(self.events, 'events')
 
     def support_event(self, event_name):
@@ -315,13 +314,8 @@ class SampleSource(Source):
 
     def __init__(self, cfg):
         super(SampleSource, self).__init__(cfg)
-        try:
-            # Support 'counters' for backward compatibility
-            self.meters = cfg.get('meters', cfg.get('counters'))
-        except KeyError as err:
-            raise PipelineException(
-                "Required field %s not specified" % err.args[0], cfg)
-
+        # Support 'counters' for backward compatibility
+        self.meters = cfg.get('meters', cfg.get('counters'))
         try:
             self.interval = int(cfg.get('interval', 600))
         except ValueError:
@@ -412,7 +406,7 @@ class Sink(object):
                     "No transformer named %s loaded" % transformer['name'],
                     cfg)
             transformers.append(ext.plugin(**parameter))
-            LOG.info(_(
+            LOG.info(_LI(
                 "Pipeline %(pipeline)s: Setup transformer instance %(name)s "
                 "with parameter %(param)s") % ({'pipeline': self,
                                                 'name': transformer['name'],
@@ -689,8 +683,7 @@ class PipelineManager(object):
         "meter_name" will be excluded; 'meter_name' means 'meter_name'
         will be included.
 
-        The 'meter_name" is Sample name field. For meter names with
-        variable like "instance:m1.tiny", it's "instance:*".
+        The 'meter_name" is Sample name field.
 
         Valid meters definition is all "included meter names", all
         "excluded meter names", wildcard and "excluded meter names", or
@@ -709,7 +702,7 @@ class PipelineManager(object):
         if not ('sources' in cfg and 'sinks' in cfg):
             raise PipelineException("Both sources & sinks are required",
                                     cfg)
-        LOG.info(_('detected decoupled pipeline config format'))
+        LOG.info(_LI('detected decoupled pipeline config format'))
 
         unique_names = set()
         sources = []
@@ -771,7 +764,7 @@ class PollingManager(object):
         if not ('sources' in cfg and 'sinks' in cfg):
             raise PipelineException("Both sources & sinks are required",
                                     cfg)
-        LOG.info(_('detected decoupled pipeline config format'))
+        LOG.info(_LI('detected decoupled pipeline config format'))
 
         unique_names = set()
         for s in cfg.get('sources', []):
@@ -795,7 +788,7 @@ def _setup_pipeline_manager(cfg_file, transformer_manager, p_type=SAMPLE_TYPE):
         data = fap.read()
 
     pipeline_cfg = yaml.safe_load(data)
-    LOG.info(_("Pipeline config: %s"), pipeline_cfg)
+    LOG.info(_LI("Pipeline config: %s"), pipeline_cfg)
 
     return PipelineManager(pipeline_cfg,
                            transformer_manager or
@@ -814,7 +807,7 @@ def _setup_polling_manager(cfg_file):
         data = fap.read()
 
     pipeline_cfg = yaml.safe_load(data)
-    LOG.info(_("Pipeline config: %s"), pipeline_cfg)
+    LOG.info(_LI("Pipeline config: %s"), pipeline_cfg)
 
     return PollingManager(pipeline_cfg)
 
