@@ -34,7 +34,7 @@ from sqlalchemy.orm import aliased
 from sqlalchemy.sql.expression import cast
 
 import ceilometer
-from ceilometer.i18n import _
+from ceilometer.i18n import _, _LI
 from ceilometer import storage
 from ceilometer.storage import base
 from ceilometer.storage import models as api_models
@@ -157,8 +157,12 @@ def make_query_from_filter(session, query, sample_filter, require_meter=True):
         else:
             query = query.filter(models.Sample.timestamp < ts_end)
     if sample_filter.user:
+        if sample_filter.user == 'None':
+            sample_filter.user = None
         query = query.filter(models.Resource.user_id == sample_filter.user)
     if sample_filter.project:
+        if sample_filter.project == 'None':
+            sample_filter.project = None
         query = query.filter(
             models.Resource.project_id == sample_filter.project)
     if sample_filter.resource:
@@ -307,8 +311,9 @@ class Connection(base.Connection):
                                     {'id': internal_id, 'meta_key': key,
                                      'value': v})
                             except KeyError:
-                                LOG.warn(_("Unknown metadata type. Key (%s) "
-                                         "will not be queryable."), key)
+                                LOG.warning(_("Unknown metadata type. Key "
+                                              "(%s) will not be queryable."),
+                                            key)
                         for _model in meta_map.keys():
                             conn.execute(_model.__table__.insert(),
                                          meta_map[_model])
@@ -356,7 +361,7 @@ class Connection(base.Connection):
         Clearing occurs according to the time-to-live.
         :param ttl: Number of seconds to keep records for.
         """
-        # Prevent database deadlocks from occuring by
+        # Prevent database deadlocks from occurring by
         # using separate transaction for each delete
         session = self._engine_facade.get_session()
         with session.begin():
@@ -364,7 +369,7 @@ class Connection(base.Connection):
             sample_q = (session.query(models.Sample)
                         .filter(models.Sample.timestamp < end))
             rows = sample_q.delete()
-            LOG.info(_("%d samples removed from database"), rows)
+            LOG.info(_LI("%d samples removed from database"), rows)
 
         if not cfg.CONF.sql_expire_samples_only:
             with session.begin():
@@ -400,8 +405,8 @@ class Connection(base.Connection):
                               .filter(models.Resource.metadata_hash
                                       .like('delete_%')))
                 resource_q.delete(synchronize_session=False)
-            LOG.info(_("Expired residual resource and"
-                       " meter definition data"))
+            LOG.info(_LI("Expired residual resource and"
+                         " meter definition data"))
 
     def get_resources(self, user=None, project=None, source=None,
                       start_timestamp=None, start_timestamp_op=None,
@@ -493,7 +498,7 @@ class Connection(base.Connection):
             )
 
     def get_meters(self, user=None, project=None, resource=None, source=None,
-                   metaquery=None, limit=None):
+                   metaquery=None, limit=None, unique=False):
         """Return an iterable of api_models.Meter instances
 
         :param user: Optional ID for user that owns the resource.
@@ -502,6 +507,7 @@ class Connection(base.Connection):
         :param source: Optional source filter.
         :param metaquery: Optional dict with metadata to match on.
         :param limit: Maximum number of results to return.
+        :param unique: If set to true, return only unique meter information.
         """
         if limit == 0:
             return
@@ -514,10 +520,17 @@ class Connection(base.Connection):
         # NOTE(gordc): get latest sample of each meter/resource. we do not
         #              filter here as we want to filter only on latest record.
         session = self._engine_facade.get_session()
+
         subq = session.query(func.max(models.Sample.id).label('id')).join(
             models.Resource,
-            models.Resource.internal_id == models.Sample.resource_id).group_by(
-            models.Sample.meter_id, models.Resource.resource_id)
+            models.Resource.internal_id == models.Sample.resource_id)
+
+        if unique:
+            subq = subq.group_by(models.Sample.meter_id)
+        else:
+            subq = subq.group_by(models.Sample.meter_id,
+                                 models.Resource.resource_id)
+
         if resource:
             subq = subq.filter(models.Resource.resource_id == resource)
         subq = subq.subquery()
@@ -538,15 +551,27 @@ class Connection(base.Connection):
                                               require_meter=False)
 
         query_sample = query_sample.limit(limit) if limit else query_sample
-        for row in query_sample.all():
-            yield api_models.Meter(
-                name=row.name,
-                type=row.type,
-                unit=row.unit,
-                resource_id=row.resource_id,
-                project_id=row.project_id,
-                source=row.source_id,
-                user_id=row.user_id)
+
+        if unique:
+            for row in query_sample.all():
+                yield api_models.Meter(
+                    name=row.name,
+                    type=row.type,
+                    unit=row.unit,
+                    resource_id=None,
+                    project_id=None,
+                    source=None,
+                    user_id=None)
+        else:
+            for row in query_sample.all():
+                yield api_models.Meter(
+                    name=row.name,
+                    type=row.type,
+                    unit=row.unit,
+                    resource_id=row.resource_id,
+                    project_id=row.project_id,
+                    source=row.source_id,
+                    user_id=row.user_id)
 
     @staticmethod
     def _retrieve_samples(query):
