@@ -30,17 +30,12 @@ import pymongo.errors
 import six
 from six.moves.urllib import parse
 
-from ceilometer.i18n import _
+from ceilometer.i18n import _, _LI
 
 ERROR_INDEX_WITH_DIFFERENT_SPEC_ALREADY_EXISTS = 86
 
 LOG = log.getLogger(__name__)
 
-# FIXME(dhellmann): Configuration options are not part of the Oslo
-# library APIs, and should not be used like this.
-cfg.CONF.import_opt('max_retries', 'oslo_db.options', group="database")
-cfg.CONF.import_opt('retry_interval', 'oslo_db.options', group="database")
-
 EVENT_TRAIT_TYPES = {'none': 0, 'string': 1, 'integer': 2, 'float': 3,
                      'datetime': 4}
 OP_SIGN = {'lt': '$lt', 'le': '$lte', 'ne': '$ne', 'gt': '$gt', 'ge': '$gte'}
@@ -262,7 +257,7 @@ class ConnectionPool(object):
         splitted_url = netutils.urlsplit(url)
         log_data = {'db': splitted_url.scheme,
                     'nodelist': connection_options['nodelist']}
-        LOG.info(_('Connecting to %(db)s on %(nodelist)s') % log_data)
+        LOG.info(_LI('Connecting to %(db)s on %(nodelist)s') % log_data)
         client = self._mongo_connect(url)
         self._pool[pool_key] = weakref.ref(client)
         return client
@@ -270,18 +265,10 @@ class ConnectionPool(object):
     @staticmethod
     def _mongo_connect(url):
         try:
-            if cfg.CONF.database.mongodb_replica_set:
-                client = MongoProxy(
-                    pymongo.MongoClient(
-                        url, replicaSet=cfg.CONF.database.mongodb_replica_set
-                    )
-                )
-            else:
-                client = MongoProxy(pymongo.MongoClient(url))
-            return client
+            return MongoProxy(pymongo.MongoClient(url))
         except pymongo.errors.ConnectionFailure as e:
-            LOG.warn(_('Unable to connect to the database server: '
-                       '%(errmsg)s.') % {'errmsg': e})
+            LOG.warning(_('Unable to connect to the database server: '
+                        '%(errmsg)s.') % {'errmsg': e})
             raise
 
 
@@ -411,6 +398,9 @@ class QueryTransformer(object):
 
 def safe_mongo_call(call):
     def closure(*args, **kwargs):
+        # NOTE(idegtiarov) options max_retries and retry_interval have been
+        # registered in storage.__init__ in oslo_db.options.set_defaults
+        # default values for both options are 10.
         max_retries = cfg.CONF.database.max_retries
         retry_interval = cfg.CONF.database.retry_interval
         attempts = 0
@@ -423,10 +413,10 @@ def safe_mongo_call(call):
                                 'after %(retries)d retries. Giving up.') %
                               {'retries': max_retries})
                     raise
-                LOG.warn(_('Unable to reconnect to the primary mongodb: '
-                           '%(errmsg)s. Trying again in %(retry_interval)d '
-                           'seconds.') %
-                         {'errmsg': err, 'retry_interval': retry_interval})
+                LOG.warning(_('Unable to reconnect to the primary '
+                              'mongodb: %(errmsg)s. Trying again in '
+                              '%(retry_interval)d seconds.') %
+                            {'errmsg': err, 'retry_interval': retry_interval})
                 attempts += 1
                 time.sleep(retry_interval)
     return closure
@@ -470,7 +460,7 @@ class MongoProxy(object):
             self.conn.create_index(keys, name=name, *args, **kwargs)
         except pymongo.errors.OperationFailure as e:
             if e.code is ERROR_INDEX_WITH_DIFFERENT_SPEC_ALREADY_EXISTS:
-                LOG.info(_("Index %s will be recreate.") % name)
+                LOG.info(_LI("Index %s will be recreate.") % name)
                 self._recreate_index(keys, name, *args, **kwargs)
 
     @safe_mongo_call
