@@ -25,20 +25,17 @@ import webtest.app
 
 from ceilometer.publisher import utils
 from ceilometer import sample
-from ceilometer.tests import db as tests_db
 from ceilometer.tests.functional.api import v2
 
 
-class TestListEmptyMeters(v2.FunctionalTest,
-                          tests_db.MixinTestsWithBackendScenarios):
+class TestListEmptyMeters(v2.FunctionalTest):
 
     def test_empty(self):
         data = self.get_json('/meters')
         self.assertEqual([], data)
 
 
-class TestValidateUserInput(v2.FunctionalTest,
-                            tests_db.MixinTestsWithBackendScenarios):
+class TestValidateUserInput(v2.FunctionalTest):
 
     def test_list_meters_query_float_metadata(self):
         self.assertRaises(webtest.app.AppError, self.get_json,
@@ -61,8 +58,7 @@ class TestValidateUserInput(v2.FunctionalTest,
                               'type': 'integer'}])
 
 
-class TestListMetersRestriction(v2.FunctionalTest,
-                                tests_db.MixinTestsWithBackendScenarios):
+class TestListMetersRestriction(v2.FunctionalTest):
 
     def setUp(self):
         super(TestListMetersRestriction, self).setUp()
@@ -141,8 +137,7 @@ class TestListMetersRestriction(v2.FunctionalTest,
         self.assertEqual(3, len(data))
 
 
-class TestListMeters(v2.FunctionalTest,
-                     tests_db.MixinTestsWithBackendScenarios):
+class TestListMeters(v2.FunctionalTest):
 
     def setUp(self):
         super(TestListMeters, self).setUp()
@@ -276,6 +271,13 @@ class TestListMeters(v2.FunctionalTest,
         self.assertEqual(set(['test_source', 'test_source1']),
                          set(r['source'] for r in data))
 
+    def test_list_unique_meters(self):
+        data = self.get_json('/meters?unique=True')
+        self.assertEqual(4, len(data))
+        self.assertEqual(set(['meter.test', 'meter.mine', 'meter.test.new',
+                              u'meter.accent\xe9\u0437']),
+                         set(r['name'] for r in data))
+
     def test_meters_query_with_timestamp(self):
         date_time = datetime.datetime(2012, 7, 2, 10, 41)
         isotime = date_time.isoformat()
