@@ -17,7 +17,6 @@ import socket
 import mock
 import msgpack
 from oslo_config import fixture as fixture_config
-from oslo_context import context
 import oslo_messaging
 from oslo_utils import timeutils
 from oslotest import mockpatch
@@ -25,7 +24,6 @@ from stevedore import extension
 
 from ceilometer import collector
 from ceilometer import dispatcher
-from ceilometer import messaging
 from ceilometer.publisher import utils
 from ceilometer import sample
 from ceilometer.tests import base as tests_base
@@ -102,7 +100,7 @@ class TestCollector(tests_base.BaseTestCase):
         ], propagate_map_exceptions=True)
         self.useFixture(mockpatch.Patch(
             'ceilometer.dispatcher.load_dispatcher_manager',
-            return_value=fake_dispatcher))
+            return_value=(fake_dispatcher, fake_dispatcher)))
         return plugin
 
     def _make_fake_socket(self, sample):
@@ -124,7 +122,8 @@ class TestCollector(tests_base.BaseTestCase):
 
     def test_record_metering_data(self):
         mock_dispatcher = self._setup_fake_dispatcher()
-        self.srv.dispatcher_manager = dispatcher.load_dispatcher_manager()
+        dps = dispatcher.load_dispatcher_manager()
+        (self.srv.meter_manager, self.srv.manager) = dps
         self.srv.record_metering_data(None, self.counter)
         mock_dispatcher.record_metering_data.assert_called_once_with(
             data=self.counter)
@@ -187,6 +186,7 @@ class TestCollector(tests_base.BaseTestCase):
 
     def test_udp_receive_bad_decoding(self):
         self._setup_messaging(False)
+        self._setup_fake_dispatcher()
         udp_socket = self._make_fake_socket(self.counter)
         with mock.patch('socket.socket', return_value=udp_socket):
             with mock.patch('msgpack.loads', self._raise_error):
@@ -199,23 +199,13 @@ class TestCollector(tests_base.BaseTestCase):
     def test_only_udp(self, udp_start, rpc_start):
         """Check that only UDP is started if messaging transport is unset."""
         self._setup_messaging(False)
+        self._setup_fake_dispatcher()
         udp_socket = self._make_fake_socket(self.counter)
         with mock.patch('socket.socket', return_value=udp_socket):
             self.srv.start()
             self.assertEqual(0, rpc_start.call_count)
             self.assertEqual(1, udp_start.call_count)
 
-    @mock.patch.object(oslo_messaging.MessageHandlingServer, 'start')
-    @mock.patch.object(collector.CollectorService, 'start_udp')
-    def test_only_rpc(self, udp_start, rpc_start):
-        """Check that only RPC is started if udp_address is empty."""
-        self.CONF.set_override('enable_rpc', True, group='collector')
-        self.CONF.set_override('udp_address', '', group='collector')
-        self.srv.start()
-        # two calls because two servers (notification and rpc)
-        self.assertEqual(2, rpc_start.call_count)
-        self.assertEqual(0, udp_start.call_count)
-
     def test_udp_receive_valid_encoding(self):
         self._setup_messaging(False)
         mock_dispatcher = self._setup_fake_dispatcher()
@@ -227,23 +217,7 @@ class TestCollector(tests_base.BaseTestCase):
                 mock_dispatcher.method_calls[0][1][0],
                 "not-so-secret"))
 
-    @mock.patch('ceilometer.storage.impl_log.LOG')
-    def test_collector_no_mock(self, mylog):
-        self.CONF.set_override('enable_rpc', True, group='collector')
-        self.CONF.set_override('udp_address', '', group='collector')
-        self.srv.start()
-        mylog.info.side_effect = lambda *args: self.srv.stop()
-
-        client = messaging.get_rpc_client(self.transport, version='1.0')
-        cclient = client.prepare(topic='metering')
-        cclient.cast(context.RequestContext(),
-                     'record_metering_data', data=[self.utf8_msg])
-
-        self.srv.rpc_server.wait()
-        mylog.info.assert_called_once_with(
-            'metering data test for test_run_tasks: 1')
-
-    def _test_collector_requeue(self, listener):
+    def _test_collector_requeue(self, listener, batch_listener=False):
 
         mock_dispatcher = self._setup_fake_dispatcher()
         self.srv.dispatcher_manager = dispatcher.load_dispatcher_manager()
@@ -252,7 +226,9 @@ class TestCollector(tests_base.BaseTestCase):
 
         self.srv.start()
         endp = getattr(self.srv, listener).dispatcher.endpoints[0]
-        ret = endp.sample({}, 'pub_id', 'event', {}, {})
+        ret = endp.sample([{'ctxt': {}, 'publisher_id': 'pub_id',
+                            'event_type': 'event', 'payload': {},
+                            'metadata': {}}])
         self.assertEqual(oslo_messaging.NotificationResult.REQUEUE,
                          ret)
 
@@ -260,45 +236,11 @@ class TestCollector(tests_base.BaseTestCase):
                        mock.Mock())
     @mock.patch.object(collector.CollectorService, 'start_udp', mock.Mock())
     def test_collector_sample_requeue(self):
-        self.CONF.set_override('requeue_sample_on_dispatcher_error', True,
-                               group='collector')
         self._test_collector_requeue('sample_listener')
 
     @mock.patch.object(oslo_messaging.MessageHandlingServer, 'start',
                        mock.Mock())
     @mock.patch.object(collector.CollectorService, 'start_udp', mock.Mock())
     def test_collector_event_requeue(self):
-        self.CONF.set_override('requeue_event_on_dispatcher_error', True,
-                               group='collector')
         self.CONF.set_override('store_events', True, group='notification')
         self._test_collector_requeue('event_listener')
-
-    def _test_collector_no_requeue(self, listener):
-        mock_dispatcher = self._setup_fake_dispatcher()
-        self.srv.dispatcher_manager = dispatcher.load_dispatcher_manager()
-        mock_dispatcher.record_metering_data.side_effect = (FakeException
-                                                            ('boom'))
-        mock_dispatcher.record_events.side_effect = (FakeException
-                                                     ('boom'))
-
-        self.srv.start()
-        endp = getattr(self.srv, listener).dispatcher.endpoints[0]
-        self.assertRaises(FakeException, endp.sample, {}, 'pub_id',
-                          'event', {}, {})
-
-    @mock.patch.object(oslo_messaging.MessageHandlingServer, 'start',
-                       mock.Mock())
-    @mock.patch.object(collector.CollectorService, 'start_udp', mock.Mock())
-    def test_collector_sample_no_requeue(self):
-        self.CONF.set_override('requeue_sample_on_dispatcher_error', False,
-                               group='collector')
-        self._test_collector_no_requeue('sample_listener')
-
-    @mock.patch.object(oslo_messaging.MessageHandlingServer, 'start',
-                       mock.Mock())
-    @mock.patch.object(collector.CollectorService, 'start_udp', mock.Mock())
-    def test_collector_event_no_requeue(self):
-        self.CONF.set_override('requeue_event_on_dispatcher_error', False,
-                               group='collector')
-        self.CONF.set_override('store_events', True, group='notification')
-        self._test_collector_no_requeue('event_listener')
