@@ -16,11 +16,11 @@
 
 import shutil
 
-import eventlet
 import mock
 from oslo_config import fixture as fixture_config
 from oslo_context import context
 import oslo_messaging
+import oslo_messaging.conffixture
 import oslo_service.service
 from oslo_utils import fileutils
 from oslo_utils import timeutils
@@ -92,6 +92,7 @@ class TestNotification(tests_base.BaseTestCase):
         super(TestNotification, self).setUp()
         self.CONF = self.useFixture(fixture_config.Config()).conf
         self.CONF.set_override("connection", "log://", group='database')
+        self.CONF.set_override("backend_url", None, group="coordination")
         self.CONF.set_override("store_events", False, group="notification")
         self.CONF.set_override("disable_non_metric_meters", False,
                                group="notification")
@@ -131,9 +132,11 @@ class TestNotification(tests_base.BaseTestCase):
         self._do_process_notification_manager_start()
         self.srv.pipeline_manager.pipelines[0] = mock.MagicMock()
 
-        self.plugin.info(TEST_NOTICE_CTXT, 'compute.vagrant-precise',
-                         'compute.instance.create.end',
-                         TEST_NOTICE_PAYLOAD, TEST_NOTICE_METADATA)
+        self.plugin.info([{'ctxt': TEST_NOTICE_CTXT,
+                           'publisher_id': 'compute.vagrant-precise',
+                           'event_type': 'compute.instance.create.end',
+                           'payload': TEST_NOTICE_PAYLOAD,
+                           'metadata': TEST_NOTICE_METADATA}])
 
         self.assertEqual(1, len(self.srv.listeners[0].dispatcher.endpoints))
         self.assertTrue(self.srv.pipeline_manager.publisher.called)
@@ -153,8 +156,10 @@ class TestNotification(tests_base.BaseTestCase):
                          self.srv.listeners[0].dispatcher.endpoints[0])
 
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
-    @mock.patch('oslo_messaging.get_notification_listener')
-    def test_unique_consumers(self, mock_listener):
+    @mock.patch.object(oslo_messaging.MessageHandlingServer, 'start',
+                       mock.MagicMock())
+    @mock.patch('ceilometer.event.endpoint.EventsNotificationEndpoint')
+    def test_unique_consumers(self, fake_event_endpoint_class):
 
         def fake_get_notifications_manager_dup_targets(pm):
             plugin = instance.Instance(pm)
@@ -166,10 +171,7 @@ class TestNotification(tests_base.BaseTestCase):
                                '_get_notifications_manager') as get_nm:
             get_nm.side_effect = fake_get_notifications_manager_dup_targets
             self.srv.start()
-            self.assertEqual(1, len(mock_listener.call_args_list))
-            args, kwargs = mock_listener.call_args
-            self.assertEqual(1, len(args[1]))
-            self.assertIsInstance(args[1][0], oslo_messaging.Target)
+            self.assertEqual(1, len(self.srv.listeners[0].dispatcher.targets))
 
 
 class BaseRealNotification(tests_base.BaseTestCase):
@@ -226,6 +228,7 @@ class BaseRealNotification(tests_base.BaseTestCase):
 
         self.expected_samples = 2
 
+        self.CONF.set_override("backend_url", None, group="coordination")
         self.CONF.set_override("store_events", True, group="notification")
         self.CONF.set_override("disable_non_metric_meters", False,
                                group="notification")
@@ -254,7 +257,6 @@ class BaseRealNotification(tests_base.BaseTestCase):
             if (len(self.publisher.samples) >= self.expected_samples and
                     len(self.publisher.events) >= self.expected_events):
                 break
-            eventlet.sleep(0)
         self.assertNotEqual(self.srv.listeners, self.srv.pipeline_listeners)
         self.srv.stop()
 
@@ -284,115 +286,46 @@ class TestRealNotificationReloadablePipeline(BaseRealNotification):
                       self.srv.tg.add_timer.call_args_list)
         self.srv.stop()
 
-    @mock.patch('ceilometer.publisher.test.TestPublisher')
-    def test_notification_reloaded_pipeline(self, fake_publisher_cls):
-        fake_publisher_cls.return_value = self.publisher
-
+    def test_notification_reloaded_pipeline(self):
         pipeline_cfg_file = self.setup_pipeline(['instance'])
         self.CONF.set_override("pipeline_cfg_file", pipeline_cfg_file)
 
-        self.expected_samples = 1
         self.srv.start()
 
-        notifier = messaging.get_notifier(self.transport,
-                                          "compute.vagrant-precise")
-        notifier.info(context.RequestContext(), 'compute.instance.create.end',
-                      TEST_NOTICE_PAYLOAD)
+        pipeline = self.srv.pipe_manager
 
-        start = timeutils.utcnow()
-        while timeutils.delta_seconds(start, timeutils.utcnow()) < 600:
-            if (len(self.publisher.samples) >= self.expected_samples and
-                    len(self.publisher.events) >= self.expected_events):
-                break
-            eventlet.sleep(0)
-
-        self.assertEqual(self.expected_samples, len(self.publisher.samples))
-
-        # Flush publisher samples to test reloading
-        self.publisher.samples = []
         # Modify the collection targets
         updated_pipeline_cfg_file = self.setup_pipeline(['vcpus',
                                                          'disk.root.size'])
         # Move/re-name the updated pipeline file to the original pipeline
         # file path as recorded in oslo config
         shutil.move(updated_pipeline_cfg_file, pipeline_cfg_file)
+        self.srv.refresh_pipeline()
 
-        self.expected_samples = 2
-        # Random sleep to let the pipeline poller complete the reloading
-        eventlet.sleep(3)
-        # Send message again to verify the reload works
-        notifier = messaging.get_notifier(self.transport,
-                                          "compute.vagrant-precise")
-        notifier.info(context.RequestContext(), 'compute.instance.create.end',
-                      TEST_NOTICE_PAYLOAD)
-
-        start = timeutils.utcnow()
-        while timeutils.delta_seconds(start, timeutils.utcnow()) < 600:
-            if (len(self.publisher.samples) >= self.expected_samples and
-                    len(self.publisher.events) >= self.expected_events):
-                break
-            eventlet.sleep(0)
-
-        self.assertEqual(self.expected_samples, len(self.publisher.samples))
-
-        (self.assertIn(sample.name, ['disk.root.size', 'vcpus'])
-         for sample in self.publisher.samples)
+        self.assertNotEqual(pipeline, self.srv.pipe_manager)
         self.srv.stop()
 
-    @mock.patch('ceilometer.publisher.test.TestPublisher')
-    def test_notification_reloaded_event_pipeline(self, fake_publisher_cls):
-        fake_publisher_cls.return_value = self.publisher
-
+    def test_notification_reloaded_event_pipeline(self):
         ev_pipeline_cfg_file = self.setup_event_pipeline(
             ['compute.instance.create.start'])
         self.CONF.set_override("event_pipeline_cfg_file", ev_pipeline_cfg_file)
 
         self.CONF.set_override("store_events", True, group="notification")
-        self.expected_events = 1
+
         self.srv.start()
 
-        notifier = messaging.get_notifier(self.transport,
-                                          "compute.vagrant-precise")
-        notifier.info(context.RequestContext(),
-                      'compute.instance.create.start',
-                      TEST_NOTICE_PAYLOAD)
+        pipeline = self.srv.event_pipe_manager
 
-        start = timeutils.utcnow()
-        while timeutils.delta_seconds(start, timeutils.utcnow()) < 600:
-            if len(self.publisher.events) >= self.expected_events:
-                break
-            eventlet.sleep(0)
-
-        self.assertEqual(self.expected_events, len(self.publisher.events))
-
-        # Flush publisher events to test reloading
-        self.publisher.events = []
         # Modify the collection targets
         updated_ev_pipeline_cfg_file = self.setup_event_pipeline(
             ['compute.instance.*'])
+
         # Move/re-name the updated pipeline file to the original pipeline
         # file path as recorded in oslo config
         shutil.move(updated_ev_pipeline_cfg_file, ev_pipeline_cfg_file)
+        self.srv.refresh_pipeline()
 
-        self.expected_events = 1
-        # Random sleep to let the pipeline poller complete the reloading
-        eventlet.sleep(3)
-        # Send message again to verify the reload works
-        notifier = messaging.get_notifier(self.transport,
-                                          "compute.vagrant-precise")
-        notifier.info(context.RequestContext(), 'compute.instance.create.end',
-                      TEST_NOTICE_PAYLOAD)
-
-        start = timeutils.utcnow()
-        while timeutils.delta_seconds(start, timeutils.utcnow()) < 600:
-            if len(self.publisher.events) >= self.expected_events:
-                break
-            eventlet.sleep(0)
-
-        self.assertEqual(self.expected_events, len(self.publisher.events))
-
-        self.assertEqual(self.publisher.events[0].event_type,
-                         'compute.instance.create.end')
+        self.assertNotEqual(pipeline, self.srv.pipe_manager)
         self.srv.stop()
 
 
@@ -419,7 +352,6 @@ class TestRealNotification(BaseRealNotification):
         while timeutils.delta_seconds(start, timeutils.utcnow()) < 600:
             if len(self.publisher.events) >= self.expected_events:
                 break
-            eventlet.sleep(0)
         self.srv.stop()
         self.assertEqual(self.expected_events, len(self.publisher.events))
 
@@ -465,28 +397,21 @@ class TestRealNotificationHA(BaseRealNotification):
             self.assertNotIn(listeners, set(self.srv.pipeline_listeners))
         self.srv.stop()
 
-    @mock.patch('oslo_messaging.get_notification_listener')
-    def test_retain_common_targets_on_refresh(self, mock_listener):
-        def generate_random_object(*args, **kwargs):
-                        return mock.MagicMock()
-
-        mock_listener.side_effect = generate_random_object
-
+    def test_retain_common_listeners_on_refresh(self):
         with mock.patch('ceilometer.coordination.PartitionCoordinator'
                         '.extract_my_subset', return_value=[1, 2]):
             self.srv.start()
-        listened_before = [target.topic for target in
-                           mock_listener.call_args[0][1]]
-        self.assertEqual(1, len(listened_before))
+        self.assertEqual(4, len(self.srv.pipeline_listeners))
+        listeners = [listener for listener in self.srv.pipeline_listeners]
         with mock.patch('ceilometer.coordination.PartitionCoordinator'
                         '.extract_my_subset', return_value=[1, 3]):
             self.srv._refresh_agent(None)
-        listened_after = [target.topic for target in
-                          mock_listener.call_args[0][1]]
-        self.assertEqual(1, len(listened_after))
-        common = set(listened_before) & set(listened_after)
-        for topic in common:
-            self.assertTrue(topic.endswith('1'))
+        self.assertEqual(4, len(self.srv.pipeline_listeners))
+        for listener in listeners:
+            if listener.dispatcher.targets[0].topic.endswith('1'):
+                self.assertIn(listener, set(self.srv.pipeline_listeners))
+            else:
+                self.assertNotIn(listener, set(self.srv.pipeline_listeners))
         self.srv.stop()
 
     @mock.patch('oslo_messaging.Notifier.sample')
@@ -497,9 +422,12 @@ class TestRealNotificationHA(BaseRealNotification):
                 not endpoint.filter_rule.match(None, None, 'nonmatching.end',
                                                None, None)):
                 continue
-            endpoint.info(TEST_NOTICE_CTXT, 'compute.vagrant-precise',
-                          'nonmatching.end',
-                          TEST_NOTICE_PAYLOAD, TEST_NOTICE_METADATA)
+            endpoint.info([{
+                'ctxt': TEST_NOTICE_CTXT,
+                'publisher_id': 'compute.vagrant-precise',
+                'event_type': 'nonmatching.end',
+                'payload': TEST_NOTICE_PAYLOAD,
+                'metadata': TEST_NOTICE_METADATA}])
         self.assertFalse(mock_notifier.called)
         for endpoint in self.srv.listeners[0].dispatcher.endpoints:
             if (hasattr(endpoint, 'filter_rule') and
@@ -507,9 +435,13 @@ class TestRealNotificationHA(BaseRealNotification):
                                                'compute.instance.create.end',
                                                None, None)):
                 continue
-            endpoint.info(TEST_NOTICE_CTXT, 'compute.vagrant-precise',
-                          'compute.instance.create.end',
-                          TEST_NOTICE_PAYLOAD, TEST_NOTICE_METADATA)
+            endpoint.info([{
+                'ctxt': TEST_NOTICE_CTXT,
+                'publisher_id': 'compute.vagrant-precise',
+                'event_type': 'compute.instance.create.end',
+                'payload': TEST_NOTICE_PAYLOAD,
+                'metadata': TEST_NOTICE_METADATA}])
+
         self.assertTrue(mock_notifier.called)
         self.assertEqual(3, mock_notifier.call_count)
         self.assertEqual('pipeline.event',
@@ -552,6 +484,7 @@ class TestRealNotificationMultipleAgents(tests_base.BaseTestCase):
 
         pipeline_cfg_file = self.setup_pipeline(['instance', 'memory'])
         self.CONF.set_override("pipeline_cfg_file", pipeline_cfg_file)
+        self.CONF.set_override("backend_url", None, group="coordination")
         self.CONF.set_override("store_events", False, group="notification")
         self.CONF.set_override("disable_non_metric_meters", False,
                                group="notification")
@@ -591,7 +524,6 @@ class TestRealNotificationMultipleAgents(tests_base.BaseTestCase):
                 if (len(self.publisher.samples + self.publisher2.samples) >=
                         self.expected_samples):
                     break
-                eventlet.sleep(0)
             self.srv.stop()
             self.srv2.stop()
 
