@@ -39,10 +39,10 @@ if [ -d $BASE/new/devstack ]; then
 fi
 
 openstack catalog list
-export AODH_SERVICE_URL=$(openstack catalog show alarming -c endpoints -f value | awk '/publicURL/{print $2}')
-export GNOCCHI_SERVICE_URL=$(openstack catalog show metric -c endpoints -f value | awk '/publicURL/{print $2}')
-export HEAT_SERVICE_URL=$(openstack catalog show orchestration -c endpoints -f value | awk '/publicURL/{print $2}')
-export NOVA_SERVICE_URL=$(openstack catalog show compute -c endpoints -f value | awk '/publicURL/{print $2}')
+export AODH_SERVICE_URL=$(openstack catalog show alarming -c endpoints -f value | awk '/public/{print $2}')
+export GNOCCHI_SERVICE_URL=$(openstack catalog show metric -c endpoints -f value | awk '/public/{print $2}')
+export HEAT_SERVICE_URL=$(openstack catalog show orchestration -c endpoints -f value | awk '/public/{print $2}')
+export NOVA_SERVICE_URL=$(openstack catalog show compute -c endpoints -f value | awk '/public/{print $2}')
 export GLANCE_IMAGE_NAME=$(openstack image list | awk '/ cirros.*uec /{print $4}')
 export ADMIN_TOKEN=$(openstack token issue -c id -f value)
 
@@ -53,6 +53,9 @@ set +e
 sudo -E -H -u ${STACK_USER:-${USER}} tox -eintegration
 EXIT_CODE=$?
 
+echo "* Message queue status:"
+sudo rabbitmqctl list_queues | grep -e \\.sample -e \\.info
+
 if [ $EXIT_CODE -ne 0 ] ; then
     set +x
     echo "* Heat stack:"
@@ -62,20 +65,24 @@ if [ $EXIT_CODE -ne 0 ] ; then
     echo "* Nova instance list:"
     openstack server list
 
-    # TODO(sileht): replace by gnocchiclient when available
     echo "* Gnocchi instance list:"
-    curl -s -X GET -H 'Content-Type: application/json' -H "X-Auth-Token: $ADMIN_TOKEN" $GNOCCHI_SERVICE_URL/v1/resource/instance | python -m "json.tool"
+    gnocchi resource list -t instance
     for instance_id in $(openstack server list -f value -c ID); do
         echo "* Nova instance detail:"
         openstack server show $instance_id
-
+        echo "* Gnocchi instance detail:"
+        gnocchi resource show -t instance $instance_id
         echo "* Gnocchi measures for instance ${instance_id}:"
-        output=$(curl -s -X GET -H 'Content-Type: application/json' -H "X-Auth-Token: $ADMIN_TOKEN" $GNOCCHI_SERVICE_URL/v1/resource/instance/$instance_id/metric/cpu_util/measures)
-        echo $output | python -m "json.tool" || echo -e "\n$output"
+        gnocchi measures show -r $instance_id cpu_util
     done
 
+    gnocchi status
+
+    # Be sure to source Gnocchi settings before
+    source $BASE/new/gnocchi/devstack/settings
     echo "* Unprocessed measures:"
-    find $GNOCCHI_DATA_DIR/measures
+    sudo find $GNOCCHI_DATA_DIR
+
     set -x
 fi
 
