@@ -249,6 +249,12 @@ class BaseAgentManagerTestCase(base.BaseTestCase):
     @mock.patch('ceilometer.pipeline.setup_polling', mock.MagicMock())
     def setUp(self):
         super(BaseAgentManagerTestCase, self).setUp()
+        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF.set_override(
+            'pipeline_cfg_file',
+            self.path_get('etc/ceilometer/pipeline.yaml')
+        )
+        self.CONF(args=[])
         self.mgr = self.create_manager()
         self.mgr.extensions = self.create_extension_list()
         self.mgr.partition_coordinator = mock.MagicMock()
@@ -269,11 +275,6 @@ class BaseAgentManagerTestCase(base.BaseTestCase):
                 'publishers': ["test"]}]
         }
         self.setup_polling()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
-        self.CONF.set_override(
-            'pipeline_cfg_file',
-            self.path_get('etc/ceilometer/pipeline.yaml')
-        )
         self.useFixture(mockpatch.PatchObject(
             publisher, 'get_publisher', side_effect=self.get_publisher))
 
@@ -353,7 +354,7 @@ class BaseAgentManagerTestCase(base.BaseTestCase):
     def test_setup_polling_tasks(self):
         polling_tasks = self.mgr.setup_polling_tasks()
         self.assertEqual(1, len(polling_tasks))
-        self.assertTrue(60 in polling_tasks.keys())
+        self.assertIn(60, polling_tasks.keys())
         per_task_resources = polling_tasks[60].resources
         self.assertEqual(1, len(per_task_resources))
         self.assertEqual(set(self.pipeline_cfg['sources'][0]['resources']),
@@ -370,8 +371,8 @@ class BaseAgentManagerTestCase(base.BaseTestCase):
         self.setup_polling()
         polling_tasks = self.mgr.setup_polling_tasks()
         self.assertEqual(2, len(polling_tasks))
-        self.assertTrue(60 in polling_tasks.keys())
-        self.assertTrue(10 in polling_tasks.keys())
+        self.assertIn(60, polling_tasks.keys())
+        self.assertIn(10, polling_tasks.keys())
 
     def test_setup_polling_tasks_mismatch_counter(self):
         self.pipeline_cfg['sources'].append({
@@ -383,8 +384,8 @@ class BaseAgentManagerTestCase(base.BaseTestCase):
         })
         polling_tasks = self.mgr.setup_polling_tasks()
         self.assertEqual(1, len(polling_tasks))
-        self.assertTrue(60 in polling_tasks.keys())
-        self.assertFalse(10 in polling_tasks.keys())
+        self.assertIn(60, polling_tasks.keys())
+        self.assertNotIn(10, polling_tasks.keys())
 
     def test_setup_polling_task_same_interval(self):
         self.pipeline_cfg['sources'].append({
@@ -553,7 +554,7 @@ class BaseAgentManagerTestCase(base.BaseTestCase):
         self.setup_polling()
         polling_tasks = self.mgr.setup_polling_tasks()
         self.assertEqual(1, len(polling_tasks))
-        self.assertTrue(60 in polling_tasks.keys())
+        self.assertIn(60, polling_tasks.keys())
         self.mgr.interval_task(polling_tasks.get(60))
         self.assertEqual([None], self.Discovery.params)
         self.assertEqual([None], self.DiscoveryAnother.params)
@@ -592,7 +593,7 @@ class BaseAgentManagerTestCase(base.BaseTestCase):
         self.setup_polling()
         polling_tasks = self.mgr.setup_polling_tasks()
         self.assertEqual(1, len(polling_tasks))
-        self.assertTrue(60 in polling_tasks.keys())
+        self.assertIn(60, polling_tasks.keys())
         self.mgr.interval_task(polling_tasks.get(60))
         self.assertEqual(1, len(self.Pollster.samples))
         self.assertEqual(['discovered_1', 'discovered_2'],
@@ -619,7 +620,7 @@ class BaseAgentManagerTestCase(base.BaseTestCase):
         self.setup_polling()
         polling_tasks = self.mgr.setup_polling_tasks()
         self.assertEqual(1, len(polling_tasks))
-        self.assertTrue(60 in polling_tasks.keys())
+        self.assertIn(60, polling_tasks.keys())
         self.mgr.interval_task(polling_tasks.get(60))
         self.assertEqual(1, len(self.Pollster.samples))
         self.assertEqual(['discovered_1', 'discovered_2'],
