@@ -12,18 +12,16 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-"""Tests for ceilometer/central/manager.py
-"""
+"""Tests for ceilometer agent manager"""
 
 import shutil
 
-import eventlet
 from keystoneclient import exceptions as ks_exceptions
 import mock
 from novaclient import client as novaclient
+from oslo_config import fixture as fixture_config
 from oslo_service import service as os_service
 from oslo_utils import fileutils
-from oslo_utils import timeutils
 from oslotest import base
 from oslotest import mockpatch
 import requests
@@ -52,6 +50,10 @@ class TestPollsterBuilder(agentbase.TestPollster):
             'BaseComputePollster.setup_environment',
             mock.Mock(return_value=None))
 class TestManager(base.BaseTestCase):
+    def setUp(self):
+        super(TestManager, self).setUp()
+        self.conf = self.useFixture(fixture_config.Config()).conf
+        self.conf(args=[])
 
     @mock.patch('ceilometer.pipeline.setup_polling', mock.MagicMock())
     def test_load_plugins(self):
@@ -102,8 +104,7 @@ class TestManager(base.BaseTestCase):
             'power', 'temperature', 'outlet_temperature',
             'airflow', 'cups', 'cpu_util', 'mem_util', 'io_util']
         calls = [mock.call(err_msg % n) for n in pollster_names]
-        LOG.error.assert_has_calls(calls=calls,
-                                   any_order=True)
+        LOG.exception.assert_has_calls(calls=calls, any_order=True)
 
     # Skip loading pollster upon ImportError
     @mock.patch('ceilometer.ipmi.pollsters.node._Base.__init__',
@@ -169,7 +170,7 @@ class TestManager(base.BaseTestCase):
 class TestPollsterKeystone(agentbase.TestPollster):
     def get_samples(self, manager, cache, resources):
         # Just try to use keystone, that will raise an exception
-        manager.keystone.tenants.list()
+        manager.keystone.projects.list()
 
 
 class TestPollsterPollingException(agentbase.TestPollster):
@@ -408,11 +409,9 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
 
         self.mgr.tg = os_service.threadgroup.ThreadGroup(1000)
         self.mgr.start()
-        start = timeutils.utcnow()
-        while timeutils.delta_seconds(start, timeutils.utcnow()) < 600:
-            if len(self.notified_samples) >= expected_samples:
-                break
-            eventlet.sleep(0)
+        # Manually executes callbacks
+        for timer in self.mgr.pollster_timers:
+            timer.f(*timer.args, **timer.kw)
 
         samples = self.notified_samples
         self.assertEqual(expected_samples, len(samples))
@@ -442,12 +441,6 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         self.CONF.set_override("pipeline_cfg_file", pipeline_cfg_file)
         self.mgr.tg = os_service.threadgroup.ThreadGroup(1000)
         self.mgr.start()
-        expected_samples = 1
-        start = timeutils.utcnow()
-        while timeutils.delta_seconds(start, timeutils.utcnow()) < 600:
-            if len(self.notified_samples) >= expected_samples:
-                break
-            eventlet.sleep(0)
 
         # we only got the old name of meters
         for sample in self.notified_samples:
@@ -475,20 +468,10 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         # file path as recorded in oslo config
         shutil.move(updated_pipeline_cfg_file, pipeline_cfg_file)
 
-        # Random sleep to let the pipeline poller complete the reloading
-        eventlet.sleep(3)
-
         # Flush notified samples to test only new, nothing latent on
         # fake message bus.
         self.notified_samples = []
 
-        expected_samples = 1
-        start = timeutils.utcnow()
-        while timeutils.delta_seconds(start, timeutils.utcnow()) < 600:
-            if len(self.notified_samples) >= expected_samples:
-                break
-            eventlet.sleep(0)
-
         # we only got the new name of meters
         for sample in self.notified_samples:
             self.assertEqual('testanother', sample['counter_name'])
