@@ -29,23 +29,23 @@ class FakeObjectName(object):
     def __init__(self, name):
         self.name = name
 
-    def prettyPrint(self):
+    def __str__(self):
         return str(self.name)
 
 
-class FakeCommandGenerator(object):
-    def getCmd(self, authData, transportTarget, *oids, **kwargs):
-        varBinds = [(FakeObjectName(oid),
-                    int(oid.split('.')[-1])) for oid in oids]
-        return (None, None, 0, varBinds)
+def faux_getCmd_new(authData, transportTarget, *oids, **kwargs):
+    varBinds = [(FakeObjectName(oid),
+                 int(oid.split('.')[-1])) for oid in oids]
+    return (None, None, 0, varBinds)
 
-    def bulkCmd(authData, transportTarget, nonRepeaters, maxRepetitions,
-                *oids, **kwargs):
-        varBindTable = [
-            [(FakeObjectName("%s.%d" % (oid, i)), i) for i in range(1, 3)]
-            for oid in oids
-        ]
-        return (None, None, 0, varBindTable)
+
+def faux_bulkCmd_new(authData, transportTarget, nonRepeaters, maxRepetitions,
+                     *oids, **kwargs):
+    varBindTable = [
+        [(FakeObjectName(oid + ".%d" % i), i) for i in range(1, 3)]
+        for oid in oids
+    ]
+    return (None, None, 0, varBindTable)
 
 
 class TestSNMPInspector(test_base.BaseTestCase):
@@ -73,8 +73,9 @@ class TestSNMPInspector(test_base.BaseTestCase):
         self.inspector = snmp.SNMPInspector()
         self.host = netutils.urlsplit("snmp://localhost")
         self.useFixture(mockpatch.PatchObject(
-            snmp.cmdgen, 'CommandGenerator',
-            return_value=FakeCommandGenerator()))
+            self.inspector._cmdGen, 'getCmd', new=faux_getCmd_new))
+        self.useFixture(mockpatch.PatchObject(
+            self.inspector._cmdGen, 'bulkCmd', new=faux_bulkCmd_new))
 
     def test_snmp_error(self):
         def get_list(func, *args, **kwargs):
@@ -132,6 +133,8 @@ class TestSNMPInspector(test_base.BaseTestCase):
         self.assertEqual(ret[0][0], ret[0][1]['meta'])
 
     def test_post_op_net(self):
+        self.useFixture(mockpatch.PatchObject(
+            self.inspector._cmdGen, 'bulkCmd', new=faux_bulkCmd_new))
         cache = {}
         metadata = dict(name='lo',
                         speed=0,
@@ -182,3 +185,25 @@ class TestSNMPInspector(test_base.BaseTestCase):
                          processed['metadata']['path'][0])
         self.assertEqual("4",
                          processed['metadata']['path'][1](4))
+
+    def test_pysnmp_ver43(self):
+        # Test pysnmp version >=4.3 compatibility of ObjectIdentifier
+        from distutils.version import StrictVersion
+        import pysnmp
+
+        has43 = StrictVersion(pysnmp.__version__) >= StrictVersion('4.3.0')
+        oid = '1.3.6.4.1.2021.11.57.0'
+
+        if has43:
+            from pysnmp.entity import engine
+            from pysnmp.smi import rfc1902
+            from pysnmp.smi import view
+            snmp_engine = engine.SnmpEngine()
+            mvc = view.MibViewController(snmp_engine.getMibBuilder())
+            name = rfc1902.ObjectIdentity(oid)
+            name.resolveWithMib(mvc)
+        else:
+            from pysnmp.proto import rfc1902
+            name = rfc1902.ObjectName(oid)
+
+        self.assertEqual(oid, str(name))
