@@ -14,13 +14,16 @@
 """
 import copy
 import mock
+import os
 import six
 import yaml
 
 from oslo_config import fixture as fixture_config
+from oslo_utils import encodeutils
 from oslo_utils import fileutils
-from oslotest import mockpatch
 
+import ceilometer
+from ceilometer import declarative
 from ceilometer.meter import notifications
 from ceilometer import service as ceilometer_service
 from ceilometer.tests import base as test
@@ -30,7 +33,9 @@ NOTIFICATION = {
     'timestamp': u'2015-06-1909: 19: 35.786893',
     'payload': {u'user_id': u'e1d870e51c7340cb9d555b15cbfcaec2',
                 u'resource_id': u'bea70e51c7340cb9d555b15cbfcaec23',
-                u'timestamp': u'2015-06-19T09: 19: 35.785330',
+                u'timestamp': u'2015-06-19T09:19:35.785330',
+                u'created_at': u'2015-06-19T09:25:35.785330',
+                u'launched_at': u'2015-06-19T09:25:40.785330',
                 u'message_signature': u'fake_signature1',
                 u'resource_metadata': {u'foo': u'bar'},
                 u'source': u'30be1fc9a03c4e94ab05c403a8a377f2: openstack',
@@ -223,31 +228,34 @@ class TestMeterDefinition(test.BaseTestCase):
                    volume="$.payload.volume",
                    resource_id="$.payload.resource_id",
                    project_id="$.payload.project_id")
-        handler = notifications.MeterDefinition(cfg)
+        handler = notifications.MeterDefinition(cfg, mock.Mock())
         self.assertTrue(handler.match_type("test.create"))
-        self.assertEqual(1.0, handler.parse_fields("volume", NOTIFICATION))
+        sample = list(handler.to_samples(NOTIFICATION))[0]
+        self.assertEqual(1.0, sample["volume"])
         self.assertEqual("bea70e51c7340cb9d555b15cbfcaec23",
-                         handler.parse_fields("resource_id", NOTIFICATION))
+                         sample["resource_id"])
         self.assertEqual("30be1fc9a03c4e94ab05c403a8a377f2",
-                         handler.parse_fields("project_id", NOTIFICATION))
+                         sample["project_id"])
 
     def test_config_required_missing_fields(self):
         cfg = dict()
         try:
-            notifications.MeterDefinition(cfg)
-        except notifications.MeterDefinitionException as e:
+            notifications.MeterDefinition(cfg, mock.Mock())
+        except declarative.DefinitionException as e:
             self.assertEqual("Required fields ['name', 'type', 'event_type',"
                              " 'unit', 'volume', 'resource_id']"
-                             " not specified", e.message)
+                             " not specified",
+                             encodeutils.exception_to_unicode(e))
 
     def test_bad_type_cfg_definition(self):
         cfg = dict(name="test", type="foo", event_type="bar.create",
                    unit="foo", volume="bar",
                    resource_id="bea70e51c7340cb9d555b15cbfcaec23")
         try:
-            notifications.MeterDefinition(cfg)
-        except notifications.MeterDefinitionException as e:
-            self.assertEqual("Invalid type foo specified", e.message)
+            notifications.MeterDefinition(cfg, mock.Mock())
+        except declarative.DefinitionException as e:
+            self.assertEqual("Invalid type foo specified",
+                             encodeutils.exception_to_unicode(e))
 
 
 class TestMeterProcessing(test.BaseTestCase):
@@ -259,22 +267,27 @@ class TestMeterProcessing(test.BaseTestCase):
         self.handler = notifications.ProcessMeterNotifications(mock.Mock())
 
     def test_fallback_meter_path(self):
-        self.useFixture(mockpatch.PatchObject(self.CONF,
-                        'find_file', return_value=None))
-        fall_bak_path = notifications.get_config_file()
-        self.assertIn("meter/data/meters.yaml", fall_bak_path)
+        self.CONF.set_override('meter_definitions_cfg_file',
+                               '/not/existing/path', group='meter')
+        with mock.patch('ceilometer.declarative.open',
+                        mock.mock_open(read_data='---\nmetric: []'),
+                        create=True) as mock_open:
+            self.handler._load_definitions()
+            if six.PY3:
+                path = os.path.dirname(ceilometer.__file__)
+            else:
+                path = "ceilometer"
+            mock_open.assert_called_with(path + "/meter/data/meters.yaml")
 
-    def __setup_meter_def_file(self, cfg):
+    def _load_meter_def_file(self, cfg):
         if six.PY3:
             cfg = cfg.encode('utf-8')
         meter_cfg_file = fileutils.write_to_tempfile(content=cfg,
                                                      prefix="meters",
                                                      suffix="yaml")
-        self.CONF.set_override(
-            'meter_definitions_cfg_file',
-            meter_cfg_file, group='meter')
-        cfg = notifications.setup_meters_config()
-        return cfg
+        self.CONF.set_override('meter_definitions_cfg_file',
+                               meter_cfg_file, group='meter')
+        self.handler.definitions = self.handler._load_definitions()
 
     @mock.patch('ceilometer.meter.notifications.LOG')
     def test_bad_meter_definition_skip(self, LOG):
@@ -297,9 +310,8 @@ class TestMeterProcessing(test.BaseTestCase):
                              volume="$.payload.volume",
                              resource_id="$.payload.resource_id",
                              project_id="$.payload.project_id")]})
-        data = self.__setup_meter_def_file(cfg)
-        meter_loaded = notifications.load_definitions(data)
-        self.assertEqual(2, len(meter_loaded))
+        self._load_meter_def_file(cfg)
+        self.assertEqual(2, len(self.handler.definitions))
         LOG.error.assert_called_with(
             "Error loading meter definition : "
             "Invalid type bad_type specified")
@@ -313,8 +325,7 @@ class TestMeterProcessing(test.BaseTestCase):
                              volume="$.payload.volume",
                              resource_id="$.payload.resource_id",
                              project_id="$.payload.project_id")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(NOTIFICATION))
         self.assertEqual(1, len(c))
         s1 = c[0].as_dict()
@@ -339,13 +350,12 @@ class TestMeterProcessing(test.BaseTestCase):
                              volume="$.payload.volume",
                              resource_id="$.payload.resource_id",
                              project_id="$.payload.project_id")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         data = list(self.handler.process_notification(NOTIFICATION))
         self.assertEqual(2, len(data))
         expected_names = ['test1', 'test2']
         for s in data:
-            self.assertTrue(s.as_dict()['name'] in expected_names)
+            self.assertIn(s.as_dict()['name'], expected_names)
 
     def test_unmatched_meter(self):
         cfg = yaml.dump(
@@ -356,8 +366,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         volume="$.payload.volume",
                         resource_id="$.payload.resource_id",
                         project_id="$.payload.project_id")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(NOTIFICATION))
         self.assertEqual(0, len(c))
 
@@ -370,8 +379,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         volume="$.payload.volume",
                         resource_id="$.payload.resource_id",
                         project_id="$.payload.project_id")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(NOTIFICATION))
         self.assertEqual(1, len(c))
 
@@ -387,8 +395,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         resource_id="$.payload.target_id",
                         project_id="$.payload.initiator.project_id",
                         multi="name")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(event))
         self.assertEqual(1, len(c))
         s1 = c[0].as_dict()
@@ -407,8 +414,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         project_id="$.payload.initiator.project_id",
                         multi="name",
                         timestamp='$.payload.eventTime')]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(event))
         self.assertEqual(1, len(c))
         s1 = c[0].as_dict()
@@ -426,8 +432,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         resource_id="'prefix-' + $.payload.nodename",
                         timestamp="$.payload.metrics"
                                   "[?(@.name='cpu.frequency')].timestamp")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(METRICS_UPDATE))
         self.assertEqual(1, len(c))
         s1 = c[0].as_dict()
@@ -443,8 +448,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         volume="$.payload.volume",
                         resource_id="$.payload.resource_id",
                         project_id="$.payload.project_id")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(NOTIFICATION))
         self.assertEqual(1, len(c))
         s1 = c[0].as_dict()
@@ -453,6 +457,23 @@ class TestMeterProcessing(test.BaseTestCase):
         meta['event_type'] = NOTIFICATION['event_type']
         self.assertEqual(meta, s1['resource_metadata'])
 
+    def test_datetime_plugin(self):
+        cfg = yaml.dump(
+            {'metric': [dict(name="test1",
+                        event_type="test.*",
+                        type="gauge",
+                        unit="sec",
+                        volume={"fields": ["$.payload.created_at",
+                                           "$.payload.launched_at"],
+                                "plugin": "timedelta"},
+                        resource_id="$.payload.resource_id",
+                        project_id="$.payload.project_id")]})
+        self._load_meter_def_file(cfg)
+        c = list(self.handler.process_notification(NOTIFICATION))
+        self.assertEqual(1, len(c))
+        s1 = c[0].as_dict()
+        self.assertEqual(5.0, s1['volume'])
+
     def test_custom_metadata(self):
         cfg = yaml.dump(
             {'metric': [dict(name="test1",
@@ -464,8 +485,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         project_id="$.payload.project_id",
                         metadata={'proj': '$.payload.project_id',
                                   'dict': '$.payload.resource_metadata'})]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(NOTIFICATION))
         self.assertEqual(1, len(c))
         s1 = c[0].as_dict()
@@ -489,8 +509,7 @@ class TestMeterProcessing(test.BaseTestCase):
                              volume="$.payload.volume",
                              resource_id="$.payload.resource_id",
                              project_id="$.payload.project_id")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(NOTIFICATION))
         self.assertEqual(2, len(c))
 
@@ -504,8 +523,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         resource_id="$.payload.target_id",
                         project_id="$.payload.initiator.project_id",
                         lookup=["name", "volume", "unit"])]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(MIDDLEWARE_EVENT))
         self.assertEqual(2, len(c))
         s1 = c[0].as_dict()
@@ -529,8 +547,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         resource_id="$.payload.target_id",
                         project_id="$.payload.initiator.project_id",
                         lookup=["name", "unit"])]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(event))
         self.assertEqual(1, len(c))
         s1 = c[0].as_dict()
@@ -550,8 +567,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         resource_id="$.payload.target_id",
                         project_id="$.payload.initiator.project_id",
                         lookup="name")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(event))
         self.assertEqual(0, len(c))
 
@@ -567,8 +583,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         user_id="$.payload.[*].user_id",
                         lookup=['name', 'type', 'unit', 'volume',
                                 'resource_id', 'project_id', 'user_id'])]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(FULL_MULTI_MSG))
         self.assertEqual(2, len(c))
         msg = FULL_MULTI_MSG['payload']
@@ -596,11 +611,11 @@ class TestMeterProcessing(test.BaseTestCase):
                         resource_id="$.payload.target_id",
                         project_id="$.payload.initiator.project_id",
                         lookup=["name", "unit", "volume"])]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(event))
         self.assertEqual(0, len(c))
-        LOG.warning.assert_called_with('Could not find %s values', 'volume')
+        LOG.warning.assert_called_with('Only 0 fetched meters contain '
+                                       '"volume" field instead of 2.')
 
     @mock.patch('ceilometer.meter.notifications.LOG')
     def test_multi_meter_payload_invalid_short(self, LOG):
@@ -615,12 +630,11 @@ class TestMeterProcessing(test.BaseTestCase):
                         resource_id="$.payload.target_id",
                         project_id="$.payload.initiator.project_id",
                         lookup=["name", "unit", "volume"])]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(event))
         self.assertEqual(0, len(c))
-        LOG.warning.assert_called_with('Not all fetched meters contain "%s" '
-                                       'field', 'volume')
+        LOG.warning.assert_called_with('Only 1 fetched meters contain '
+                                       '"volume" field instead of 2.')
 
     def test_arithmetic_expr_meter(self):
         cfg = yaml.dump(
@@ -633,8 +647,7 @@ class TestMeterProcessing(test.BaseTestCase):
                                " * 100",
                         resource_id="$.payload.host + '_'"
                                     " + $.payload.nodename")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(METRICS_UPDATE))
         self.assertEqual(1, len(c))
         s1 = c[0].as_dict()
@@ -653,8 +666,7 @@ class TestMeterProcessing(test.BaseTestCase):
                                ".value",
                         resource_id="$.payload.host + '_'"
                                     " + $.payload.nodename")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(METRICS_UPDATE))
         self.assertEqual(1, len(c))
         s1 = c[0].as_dict()
@@ -672,8 +684,7 @@ class TestMeterProcessing(test.BaseTestCase):
                         volume="$.payload.metrics[?(@.name='cpu.frequency')]"
                                ".value",
                         resource_id="'prefix-' + $.payload.nodename")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(METRICS_UPDATE))
         self.assertEqual(1, len(c))
         s1 = c[0].as_dict()
@@ -698,7 +709,6 @@ class TestMeterProcessing(test.BaseTestCase):
                              volume="$.payload.volume",
                              resource_id="$.payload.resource_id",
                              project_id="$.payload.project_id")]})
-        self.handler.definitions = notifications.load_definitions(
-            self.__setup_meter_def_file(cfg))
+        self._load_meter_def_file(cfg)
         c = list(self.handler.process_notification(NOTIFICATION))
         self.assertEqual(1, len(c))
