@@ -14,6 +14,8 @@
 # under the License.
 
 import mock
+
+from oslo_config import cfg
 from oslo_context import context
 from oslotest import base
 from oslotest import mockpatch
@@ -32,9 +34,14 @@ class _BaseTestLBPollster(base.BaseTestCase):
         self.addCleanup(mock.patch.stopall)
         self.context = context.get_admin_context()
         self.manager = manager.AgentManager()
+        cfg.CONF.set_override('neutron_lbaas_version',
+                              'v1',
+                              group='service_types')
         plugin_base._get_keystone = mock.Mock()
-        plugin_base._get_keystone.service_catalog.get_endpoints = (
-            mock.MagicMock(return_value={'network': mock.ANY}))
+        catalog = (plugin_base._get_keystone.session.auth.get_access.
+                   return_value.service_catalog)
+        catalog.get_endpoints = mock.MagicMock(
+            return_value={'network': mock.ANY})
 
 
 class TestLBPoolPollster(_BaseTestLBPollster):
@@ -467,7 +474,6 @@ class TestLBStatsPollster(_BaseTestLBPollster):
     def _check_get_samples(self, factory, sample_name, expected_volume,
                            expected_type):
         pollster = factory()
-
         cache = {}
         samples = list(pollster.get_samples(self.manager, cache,
                                             self.fake_get_pools()))
@@ -494,9 +500,9 @@ class TestLBStatsPollster(_BaseTestLBPollster):
     def test_lb_incoming_bytes(self):
         self._check_get_samples(lbaas.LBBytesInPollster,
                                 'network.services.lb.incoming.bytes',
-                                1, 'cumulative')
+                                1, 'gauge')
 
     def test_lb_outgoing_bytes(self):
         self._check_get_samples(lbaas.LBBytesOutPollster,
                                 'network.services.lb.outgoing.bytes',
-                                3, 'cumulative')
+                                3, 'gauge')
