@@ -85,20 +85,19 @@ class DeltaTransformer(BaseConversionTransformer):
             time_delta = timeutils.delta_seconds(prev_timestamp, timestamp)
             # disallow violations of the arrow of time
             if time_delta < 0:
-                LOG.warn(_LW('Dropping out of time order sample: %s'), (s,))
+                LOG.warning(_LW('Dropping out of time order sample: %s'), (s,))
                 # Reset the cache to the newer sample.
                 self.cache[key] = prev
                 return None
             volume_delta = s.volume - prev_volume
             if self.growth_only and volume_delta < 0:
-                LOG.warn(_LW('Negative delta detected, dropping value'))
+                LOG.warning(_LW('Negative delta detected, dropping value'))
                 s = None
             else:
                 s = self._convert(s, volume_delta)
                 LOG.debug('Converted to: %s', s)
         else:
-            LOG.warn(_LW('Dropping sample with no predecessor: %s'),
-                     (s,))
+            LOG.warning(_LW('Dropping sample with no predecessor: %s'), (s,))
             s = None
         return s
 
@@ -196,7 +195,7 @@ class RateOfChangeTransformer(ScalingTransformer):
             time_delta = timeutils.delta_seconds(prev_timestamp, timestamp)
             # disallow violations of the arrow of time
             if time_delta < 0:
-                LOG.warn(_('dropping out of time order sample: %s'), (s,))
+                LOG.warning(_('dropping out of time order sample: %s'), (s,))
                 # Reset the cache to the newer sample.
                 self.cache[key] = prev
                 return None
@@ -214,8 +213,8 @@ class RateOfChangeTransformer(ScalingTransformer):
             s = self._convert(s, rate_of_change)
             LOG.debug('converted to: %s', s)
         else:
-            LOG.warn(_('dropping sample with no predecessor: %s'),
-                     (s,))
+            LOG.warning(_('dropping sample with no predecessor: %s'),
+                        (s,))
             s = None
         return s
 
@@ -237,11 +236,17 @@ class AggregatorTransformer(ScalingTransformer):
 
         AggregatorTransformer(size=15, user_id='first',
                               resource_metadata='drop')
+
+      To keep the timestamp of the last received sample rather
+      than the first:
+
+        AggregatorTransformer(timestamp="last")
+
     """
 
     def __init__(self, size=1, retention_time=None,
                  project_id=None, user_id=None, resource_metadata="last",
-                 **kwargs):
+                 timestamp="first", **kwargs):
         super(AggregatorTransformer, self).__init__(**kwargs)
         self.samples = {}
         self.counts = collections.defaultdict(int)
@@ -250,6 +255,11 @@ class AggregatorTransformer(ScalingTransformer):
         if not (self.size or self.retention_time):
             self.size = 1
 
+        if timestamp in ["first", "last"]:
+            self.timestamp = timestamp
+        else:
+            self.timestamp = "first"
+
         self.initial_timestamp = None
         self.aggregated_samples = 0
 
@@ -266,7 +276,7 @@ class AggregatorTransformer(ScalingTransformer):
         drop = ['drop'] if is_droppable else []
         if value or mandatory:
             if value not in ['last', 'first'] + drop:
-                LOG.warn('%s is unknown (%s), using last' % (name, value))
+                LOG.warning('%s is unknown (%s), using last' % (name, value))
                 value = 'last'
             self.merged_attribute_policy[name] = value
         else:
@@ -296,6 +306,8 @@ class AggregatorTransformer(ScalingTransformer):
                     'resource_metadata'] == 'drop':
                 self.samples[key].resource_metadata = {}
         else:
+            if self.timestamp == "last":
+                self.samples[key].timestamp = sample_.timestamp
             if sample_.type == sample.TYPE_CUMULATIVE:
                 self.samples[key].volume = self._scale(sample_)
             else:
